#
# spec file for package python-pywinrm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pywinrm
Version:        0.4.3
Release:        2.3
Summary:        Python library for Windows Remote Management
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/diyan/pywinrm/
Source:         https://github.com/diyan/pywinrm/archive/refs/tags/v%{version}.tar.gz#/pywinrm-%{version}.tar.gz
BuildRequires:  %{python_module kerberos}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.9.1}
BuildRequires:  %{python_module requests_ntlm >= 0.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module xmltodict}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.9.1
Requires:       python-requests_ntlm >= 0.3.0
Requires:       python-six
Requires:       python-xmltodict
Suggests:       python-requests-credssp >= 0.0.1
Suggests:       python-requests-kerberos >= 0.10.0
BuildArch:      noarch
%python_subpackages

%description
pywinrm is a Python client for Windows Remote Management (WinRM). This
allows you to invoke commands on target Windows machines from any
machine that can run Python.

WinRM allows you to call native objects in Windows. This includes, but
is not limited to, running batch scripts, powershell scripts and
fetching WMI variables. For more information on WinRM, please visit
Microsoft's WinRM http://msdn.microsoft.com/en-us/library/aa384426.aspx

%prep
%setup -q -n pywinrm-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/diyan/pywinrm/issues/345
sed -i 's:import mock:from unittest import mock:' winrm/tests/test_transport.py
%pyunittest discover -v

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/*

%changelog
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Apr 14 2022 pgajdos@suse.com
- version update to 0.4.3
  * Fix invalid regex escape sequences.
  * Decoding CLIXML failures for run_ps will create a UserWarning rather than printing the warning.
  * Remove usage of deprecated Python API to support Python 3.11
- do not require mock for build
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.4.2:
  * removed deprecated distutils usage to avoid Deprecation Warnings under
    Python 3.10
* Fri May 28 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.1:
  * python 3.8
* Sun Nov  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0
  * Ensure server_cert_validation=ignore supersedes
    ca_trust_path/env overrides.
  * Added deprecated warnings if CA trusts defined by environment
    variables are used.
  * Set minimum version of requests-credssp to support Kerberos
    auth over CredSSP and other changes.
  * Added proxy support where it can be defined within the
    application, with the ability to specify the proxy within the
    application.
  * Fix for shell not setting all environment variables.
  * Fix session clixml encoding on Python 3.
  * Protocol.close_shell(shell_id) will now close the session(and
    TCP connections) to the Windows machine. close_session option
    has been added in case of leaving the session alone.
  * Add a function to send input to a running process.
- Use tarball from github instead of pypi
- Drop not longer needed file LICENSE (it's part of the upstream
  tarball
- Add %%{python_module kerberos} to BuildRequires since it's used
  in some tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Apr  5 2018 mardnh@gmx.de
- Upgrade to version 0.3.0
  * Added support for message encryption over HTTP when using NTLM/Kerberos/CredSSP
  * Added parameter to disable TLSv1.2 when using CredSSP for Server 2008 support
  * Error detail from SOAP fault (if present) is now included with HTTP 500 errors
  * Fixed CA path override (incl envvar)
  * Fixed Kerberos service override
  * Try harder to suppress urllib3 InsecureRequestWarnings on various OSs
  * Fixed timeout values to parse correctly if passed as strings
  * Various updates to CI/tests
- Convert to singlespec
* Wed Mar  8 2017 boris@steki.net
- upgraded to pypi released source 0.2.2
  + Added support for CredSSP authenication (via requests-credssp)
  + Improved README, see 'Valid transport options' section
  + Run unit tests on Linux / Travis CI on Python 2.6-2.7, 3.3-3.6, PyPy2
  + Run integration tests on Windows / AppVeyor on Python 2.7, 3.3-3.5
  + Drop support for Python 3.0-3.2 due to lack of explicit unicode literal, see pep-0414
  + Drop support for Python 2.6 on Windows
  + Add support for Python 3.6-dev on Linux
  + Force basic auth header to avoid additional HTTP request and reduce latency
  + Python 2.7.9+. Allow server cert validation to be ignored using SSLContext.verify_mode
  + Tests. Enable Python 3.4, 3.5 on Travis CI
  + Use xmltodict instead of not supported xmlwitch
  + Add certificate authentication support
  + Setup PyPI classifiers
  + Fix. Include UUID when sending request
  + Fix. Python 2.6.6/CentOS. Use tuples instead of lists in setup.py
  + Fix. Python 2.6. String formatting
  + Handle unauthorized response and raise UnauthorizeError
  + Convert different forms of short urls into full well-formed endpoint
  + Add Session.run_ps() helper to execute PowerShell scripts
  + Use pandoc for README.md to rst conversion for PyPI
* Wed Sep 10 2014 boris@steki.net
- initial packaging
